@@ -20,7 +20,11 @@ def get_nearest_index(tim_eq, tarr):
         unique_idx = [0]
         index_idx = {0: [0]}
     else:
-        idx = np.searchsorted(tim_eq, tarr)
+#        idx = np.argmin(np.abs(tim_eq[:, None] - tarr), axis=0)
+        tarr = np.minimum(np.maximum(tarr, tim_eq[0]), tim_eq[-1])
+        idx = interp1d(tim_eq, np.arange(len(tim_eq)), kind='nearest')(tarr)
+        idx = np.atleast_1d(np.int_(idx))
+#        idx = np.searchsorted(tim_eq, tarr) # not closest, either left or right
         unique_idx = np.unique(idx)
         unique_idx = np.minimum(unique_idx, len(tim_eq) - 1)
         index_idx = {}
@@ -247,8 +251,8 @@ def rz2brzt(eqm, r_in, z_in, t_in=None):
 
         jt = index_idx[i]
         Psi = eqm.pfm[:, :, i]
-        Br =  np.gradient(Psi, axis=1)/eqm.Rmesh[:, None]
-        Bz = -np.gradient(Psi, axis=0)/eqm.Rmesh[:, None]
+        Br = np.apply_along_axis(np.gradient, 1,  Psi)/eqm.Rmesh[:, None]
+        Bz = np.apply_along_axis(np.gradient, 0, -Psi)/eqm.Rmesh[:, None]
         fBt = interp1d(eqm.pfl[i], eqm.jpol[i], kind='linear', fill_value='extrapolate')
         Bt = fBt(Psi)*mu_0/eqm.Rmesh[:, None]
         r = np.squeeze(r_in[jt])
@@ -323,8 +327,8 @@ def Bmesh(eqm, t_in=None):
         jt = index_idx[i]
         Psi = eqm.pfm[:, :, i]
 # Eq 12 in COCOs paper
-        Br[jt] = np.gradient(Psi, axis=1)/eqm.Rmesh[:, None]
-        Bz[jt] = -np.gradient(Psi, axis=0)/eqm.Rmesh[:, None]
+        Br[jt] = np.apply_along_axis(np.gradient, 1,  Psi)/eqm.Rmesh[:, None]
+        Bz[jt] = np.apply_along_axis(np.gradient, 0, -Psi)/eqm.Rmesh[:, None]
         fBt = interp1d(eqm.pfl[i], eqm.jpol[i], kind='linear', fill_value='extrapolate')
         Bt[jt] = fBt(Psi)*mu_0/eqm.Rmesh[:, None]
 
