@@ -112,11 +112,11 @@ class EQU:
 
         print('COCOS %d' %self.cocos)
 
-        if 'tbeg' is kwargs.keys():
+        if 'tbeg' in kwargs.keys():
             tbeg = kwargs['tbeg']
         else:
             tbeg = np.min(self.time)
-        if 'tend' is kwargs.keys():
+        if 'tend' in kwargs.keys():
             tend = kwargs['tend']
         else:
             tend = np.max(self.time)
