@@ -1,4 +1,4 @@
-import os, sys, time, datetime
+import os, datetime
 from struct import unpack
 import numpy as np
 try:
@@ -202,7 +202,6 @@ class SFREAD:
         else:
             ed = 0
 
-        tbeg = time.time()
         self.sfile, self.ed = manage_ed.sf_path(nshot, diag, exp=exp, ed=ed)
         if self.sfile is not None:
             self.shot = nshot
@@ -286,7 +285,7 @@ class SFREAD:
         return None
 
 
-    def getobject(self, obj, cal=False):
+    def getobject(self, obj, cal=False, nbeg=None, nend=None):
         """
         Reads the data of a given TB, AB, SIG or SGR
         """
@@ -305,7 +304,7 @@ class SFREAD:
             return None
         otyp = sfo.obj_type
         if otyp in (6, 7):
-            shape_arr = sfo.index[::-1][:sfo.num_dims]
+            shape_arr = np.array(sfo.index[::-1][:sfo.num_dims])
         elif otyp == 8:
             shape_arr = np.array([sfo.n_steps])
         elif otyp == 13:
@@ -328,17 +327,29 @@ class SFREAD:
                     data = np.chararray(shape_arr, itemsize=dlen, buffer=self.getchunk(sfo.address, bytlen), order='F')
                 else: # numerical variable
                     sfmt = sfdics.fmt2struc[dfmt]
-                    dt  = np.dtype(sfdics.fmt2np[dfmt])
-                    dt = dt.newbyteorder('>')
                     type_len = np.dtype(sfmt).itemsize
+                    addr = sfo.address
                     bytlen = np.prod(shape_arr) * type_len
-                    data = np.ndarray(shape_arr, '>%s' %sfmt, self.getchunk(sfo.address, bytlen), order='F')
+                    if otyp in (7, 8) or self.time_last(obj):
+                        if nbeg is None:
+                            nbeg = 0
+                        else:
+                            byt_beg = nbeg*np.prod(shape_arr[:-1])
+                            addr   += byt_beg*type_len
+                            bytlen -= byt_beg*type_len
+                            shape_arr[-1] -= nbeg
+                        if nend is not None:
+                            bytlen = (nend - nbeg)*np.prod(shape_arr[:-1])*type_len
+                            shape_arr[-1] = nend - nbeg
+                    data = np.ndarray(shape_arr, '>%s' %sfmt, self.getchunk(addr, bytlen), order='F')
 
 # LongLong in [ns] and no zero at TS06
                 if otyp == 8 and dfmt == 13: # RMC:TIME-AD0
                     dout = 1e-9*(data - self.get_ts06())
                 else:
                     dout = sfobj.SFOBJ(data, sfho=sfo) # Add metadata
+
+# Calibrated signals and signal groups
                 if otyp in (6, 7) and cal:
                     pscal = self.lincalib(obj)
                     if pscal is not None:
@@ -529,3 +540,53 @@ class SFREAD:
             ts6 = get_cti_ts06(self.shot)
 
         return ts6
+
+
+    def time_first(self, obj):
+        """
+        Tells whether a SigGroup has time as first coordinate
+        by comparing with the size of the related TBase
+        """
+
+        obj = to_str(obj)
+        sfo = self.sfh[obj]
+        otyp = sfo.obj_type
+        if otyp != 6:
+            return False # Objects other than sig, sgr, tbase
+
+        rels = self.get_rel_names(obj)
+        for rel in rels:
+            if self.sfh[rel].obj_type == 8:
+                shape_arr = np.array(sfo.index[::-1][:sfo.num_dims])
+                nt = self.sfh[rel].n_steps
+                if shape_arr[0] != nt:
+                    return False
+                for jdim in range(1, sfo.num_dims):
+                    if shape_arr[jdim] == nt:
+                        return False # Two dimension are
+                return True # No other dim's size matches by chance
+
+
+    def time_last(self, obj):
+        """
+        Tells whether a SigGroup has time as first coordinate
+        by comparing with the size of the related TBase
+        """
+
+        obj = to_str(obj)
+        sfo = self.sfh[obj]
+        otyp = sfo.obj_type
+        if otyp != 6:
+            return False # Objects other than sig, sgr, tbase
+
+        rels = self.get_rel_names(obj)
+        for rel in rels:
+            if self.sfh[rel].obj_type == 8:
+                shape_arr = np.array(sfo.index[::-1][:sfo.num_dims])
+                nt = self.sfh[rel].n_steps
+                if shape_arr[-1] != nt:
+                    return False
+                for jdim in range(sfo.num_dims-1):
+                    if shape_arr[jdim] == nt:
+                        return False # Two dimension are
+                return True # No other dim's size matches by chance
